@@ -12,9 +12,9 @@ except ModuleNotFoundError:
     except KeyError:
 
         # 2. we use the default freecad defined for this package
-        _path_to_freecad_libdir = "C:/clangarm64/bin"
+        _path_to_freecad_libdir = "/clangarm64/bin"
         print("PATH_TO_FREECAD_LIBDIR not specified, using default \
-FreeCAD version in {}".format("C:/clangarm64/bin"))
+FreeCAD version in {}".format("/clangarm64/bin"))
 
     _sys.path.append(_path_to_freecad_libdir) # this is the default version
     import FreeCAD as app
